@@ -2,12 +2,12 @@
 
 instrumented_attr = '__sfx_instrumented'
 traceable_libraries = (
-    'celery', 'django', 'elasticsearch', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
+    'celery', 'django', 'elasticsearch', 'falcon', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
     'tornado', 'logging'
 )
 
 auto_instrumentable_libraries = (
-    'celery', 'elasticsearch', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
+    'celery', 'elasticsearch', 'falcon', 'flask', 'psycopg2', 'pymongo', 'pymysql', 'redis', 'requests',
     'tornado', 'logging'
 )
 
